/*
 * SmartDENBlindMonitorView.java
 */

package smartDEN_Notifier_MQTT;

import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JDialog;
import javax.swing.JFrame;
import org.eclipse.paho.client.mqttv3.MqttClient;
import org.eclipse.paho.client.mqttv3.MqttConnectOptions;
import org.eclipse.paho.client.mqttv3.MqttException;
import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;

/**
 * The application's main frame.
 */
public class smartDEN_Notifier_MQTTView extends FrameView {

    public smartDEN_Notifier_MQTTView(SingleFrameApplication app) {
        super(app);

        initComponents();
        
        Runtime.getRuntime().addShutdownHook(new Thread() {
            @Override
            public void run() {
                save();
            }
        });
        
        
        //ImageIcon icon = new ImageIcon("D:\\projects\\java\\smartDEN_Notifier_MQTT\\src\\smartdenblindmonitor\\resources\\LogoTransperant.PNG");
        //smartDEN_Notifier_MQTTView.pictureLabel.setIcon(icon);

        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();
        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(false);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String)(evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer)(evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
        load();
        
        /*mqttClient = new MyMqtt();
        mqttClient.readFromTopic();
        
        myMqtt = new myMqttThread();
        mqttThread = new Thread(myMqtt, "My Thread1");
        mqttThread.start();*/
        
    }

    @Action
    public void showAboutBox() {
        if (aboutBox == null) {
            JFrame mainFrame = smartDEN_Notifier_MQTTApp.getApplication().getMainFrame();
            aboutBox = new smartDEN_Notifier_MQTTAboutBox(mainFrame);
            aboutBox.setLocationRelativeTo(mainFrame);
        }
        smartDEN_Notifier_MQTTApp.getApplication().show(aboutBox);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        mqttSettingsPanel = new javax.swing.JPanel();
        startButton = new javax.swing.JButton();
        jLabel1 = new javax.swing.JLabel();
        brokerText = new javax.swing.JTextField();
        portText = new javax.swing.JTextField();
        jLabel2 = new javax.swing.JLabel();
        usernameText = new javax.swing.JTextField();
        jLabel3 = new javax.swing.JLabel();
        passwordText = new javax.swing.JTextField();
        jLabel5 = new javax.swing.JLabel();
        macText = new javax.swing.JTextField();
        stopButton = new javax.swing.JButton();
        jLabel6 = new javax.swing.JLabel();
        periodText = new javax.swing.JTextField();
        diPanel = new javax.swing.JPanel();
        diName = new javax.swing.JLabel();
        diValue = new javax.swing.JLabel();
        diName1 = new javax.swing.JLabel();
        diValue1 = new javax.swing.JLabel();
        diName2 = new javax.swing.JLabel();
        diValue2 = new javax.swing.JLabel();
        diName3 = new javax.swing.JLabel();
        diValue3 = new javax.swing.JLabel();
        diName4 = new javax.swing.JLabel();
        diValue4 = new javax.swing.JLabel();
        diName5 = new javax.swing.JLabel();
        diValue5 = new javax.swing.JLabel();
        diName6 = new javax.swing.JLabel();
        diValue6 = new javax.swing.JLabel();
        diName7 = new javax.swing.JLabel();
        diValue7 = new javax.swing.JLabel();
        diName8 = new javax.swing.JLabel();
        diValue8 = new javax.swing.JLabel();
        diName9 = new javax.swing.JLabel();
        diValue9 = new javax.swing.JLabel();
        diName10 = new javax.swing.JLabel();
        diValue10 = new javax.swing.JLabel();
        diName11 = new javax.swing.JLabel();
        diValue11 = new javax.swing.JLabel();
        diName12 = new javax.swing.JLabel();
        diValue12 = new javax.swing.JLabel();
        diName13 = new javax.swing.JLabel();
        diValue13 = new javax.swing.JLabel();
        diName14 = new javax.swing.JLabel();
        diValue14 = new javax.swing.JLabel();
        diName15 = new javax.swing.JLabel();
        diValue15 = new javax.swing.JLabel();
        diName16 = new javax.swing.JLabel();
        diValue16 = new javax.swing.JLabel();
        tiPanel = new javax.swing.JPanel();
        jLabel4 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        tiName1 = new javax.swing.JLabel();
        tiValue1 = new javax.swing.JLabel();
        tiName2 = new javax.swing.JLabel();
        tiValue2 = new javax.swing.JLabel();
        tiName3 = new javax.swing.JLabel();
        tiValue3 = new javax.swing.JLabel();
        tiName4 = new javax.swing.JLabel();
        tiValue4 = new javax.swing.JLabel();
        tiName5 = new javax.swing.JLabel();
        tiValue5 = new javax.swing.JLabel();
        tiName6 = new javax.swing.JLabel();
        tiValue6 = new javax.swing.JLabel();
        tiName7 = new javax.swing.JLabel();
        tiValue7 = new javax.swing.JLabel();
        tiName8 = new javax.swing.JLabel();
        tiValue8 = new javax.swing.JLabel();
        aiPanel = new javax.swing.JPanel();
        jLabel24 = new javax.swing.JLabel();
        jLabel25 = new javax.swing.JLabel();
        aiName1 = new javax.swing.JLabel();
        aiValue1 = new javax.swing.JLabel();
        aiName2 = new javax.swing.JLabel();
        aiValue2 = new javax.swing.JLabel();
        aiName3 = new javax.swing.JLabel();
        aiValue3 = new javax.swing.JLabel();
        aiName4 = new javax.swing.JLabel();
        aiValue4 = new javax.swing.JLabel();
        aiName5 = new javax.swing.JLabel();
        aiValue5 = new javax.swing.JLabel();
        aiName6 = new javax.swing.JLabel();
        aiValue6 = new javax.swing.JLabel();
        aiName7 = new javax.swing.JLabel();
        aiValue7 = new javax.swing.JLabel();
        aiName8 = new javax.swing.JLabel();
        aiValue8 = new javax.swing.JLabel();
        pictureLabel = new javax.swing.JLabel();
        jPanel1 = new javax.swing.JPanel();
        diValue17 = new javax.swing.JLabel();
        diValue19 = new javax.swing.JLabel();
        diValue21 = new javax.swing.JLabel();
        notificationLabel = new javax.swing.JLabel();
        datetimeLabel = new javax.swing.JLabel();
        deviceLabel = new javax.swing.JLabel();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        javax.swing.JMenu helpMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem aboutMenuItem = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();

        mainPanel.setName("mainPanel"); // NOI18N
        mainPanel.setLayout(null);

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(smartDEN_Notifier_MQTT.smartDEN_Notifier_MQTTApp.class).getContext().getResourceMap(smartDEN_Notifier_MQTTView.class);
        mqttSettingsPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("mqttSettingsPanel.border.title"))); // NOI18N
        mqttSettingsPanel.setName("mqttSettingsPanel"); // NOI18N
        mqttSettingsPanel.setLayout(null);

        startButton.setText(resourceMap.getString("startButton.text")); // NOI18N
        startButton.setName("startButton"); // NOI18N
        startButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startButtonActionPerformed(evt);
            }
        });
        mqttSettingsPanel.add(startButton);
        startButton.setBounds(390, 80, 180, 30);

        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N
        mqttSettingsPanel.add(jLabel1);
        jLabel1.setBounds(10, 20, 90, 20);

        brokerText.setText(resourceMap.getString("brokerText.text")); // NOI18N
        brokerText.setName("brokerText"); // NOI18N
        mqttSettingsPanel.add(brokerText);
        brokerText.setBounds(100, 20, 140, 20);

        portText.setText(resourceMap.getString("portText.text")); // NOI18N
        portText.setName("portText"); // NOI18N
        mqttSettingsPanel.add(portText);
        portText.setBounds(250, 20, 110, 20);

        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N
        mqttSettingsPanel.add(jLabel2);
        jLabel2.setBounds(410, 20, 80, 14);

        usernameText.setText(resourceMap.getString("usernameText.text")); // NOI18N
        usernameText.setName("usernameText"); // NOI18N
        mqttSettingsPanel.add(usernameText);
        usernameText.setBounds(500, 20, 260, 20);

        jLabel3.setText(resourceMap.getString("jLabel3.text")); // NOI18N
        jLabel3.setName("jLabel3"); // NOI18N
        mqttSettingsPanel.add(jLabel3);
        jLabel3.setBounds(410, 50, 70, 14);

        passwordText.setText(resourceMap.getString("passwordText.text")); // NOI18N
        passwordText.setName("passwordText"); // NOI18N
        mqttSettingsPanel.add(passwordText);
        passwordText.setBounds(500, 50, 260, 20);

        jLabel5.setText(resourceMap.getString("jLabel5.text")); // NOI18N
        jLabel5.setName("jLabel5"); // NOI18N
        mqttSettingsPanel.add(jLabel5);
        jLabel5.setBounds(10, 50, 22, 14);

        macText.setText(resourceMap.getString("macText.text")); // NOI18N
        macText.setName("macText"); // NOI18N
        mqttSettingsPanel.add(macText);
        macText.setBounds(100, 50, 260, 20);

        stopButton.setText(resourceMap.getString("stopButton.text")); // NOI18N
        stopButton.setEnabled(false);
        stopButton.setName("stopButton"); // NOI18N
        stopButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                stopButtonActionPerformed(evt);
            }
        });
        mqttSettingsPanel.add(stopButton);
        stopButton.setBounds(580, 80, 180, 30);

        jLabel6.setText(resourceMap.getString("jLabel6.text")); // NOI18N
        jLabel6.setName("jLabel6"); // NOI18N
        mqttSettingsPanel.add(jLabel6);
        jLabel6.setBounds(10, 80, 90, 20);

        periodText.setText(resourceMap.getString("periodText.text")); // NOI18N
        periodText.setName("periodText"); // NOI18N
        mqttSettingsPanel.add(periodText);
        periodText.setBounds(100, 80, 260, 20);

        mainPanel.add(mqttSettingsPanel);
        mqttSettingsPanel.setBounds(10, 10, 770, 120);
        mqttSettingsPanel.getAccessibleContext().setAccessibleName(resourceMap.getString("mqttSettingsPanel.AccessibleContext.accessibleName")); // NOI18N

        diPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("diPanel.border.title"))); // NOI18N
        diPanel.setName("diPanel"); // NOI18N
        diPanel.setLayout(new java.awt.GridLayout(17, 2));

        diName.setBackground(resourceMap.getColor("diName.background")); // NOI18N
        diName.setForeground(resourceMap.getColor("diName.foreground")); // NOI18N
        diName.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName.setText(resourceMap.getString("diName.text")); // NOI18N
        diName.setName("diName"); // NOI18N
        diPanel.add(diName);

        diValue.setForeground(resourceMap.getColor("diValue.foreground")); // NOI18N
        diValue.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue.setText(resourceMap.getString("diValue.text")); // NOI18N
        diValue.setName("diValue"); // NOI18N
        diPanel.add(diValue);

        diName1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName1.setText(resourceMap.getString("diName1.text")); // NOI18N
        diName1.setName("diName1"); // NOI18N
        diPanel.add(diName1);

        diValue1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue1.setText(resourceMap.getString("diValue1.text")); // NOI18N
        diValue1.setName("diValue1"); // NOI18N
        diPanel.add(diValue1);

        diName2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName2.setText(resourceMap.getString("diName2.text")); // NOI18N
        diName2.setName("diName2"); // NOI18N
        diPanel.add(diName2);

        diValue2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue2.setText(resourceMap.getString("diValue2.text")); // NOI18N
        diValue2.setName("diValue2"); // NOI18N
        diPanel.add(diValue2);

        diName3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName3.setText(resourceMap.getString("diName3.text")); // NOI18N
        diName3.setName("diName3"); // NOI18N
        diPanel.add(diName3);

        diValue3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue3.setText(resourceMap.getString("diValue3.text")); // NOI18N
        diValue3.setName("diValue3"); // NOI18N
        diPanel.add(diValue3);

        diName4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName4.setText(resourceMap.getString("diName4.text")); // NOI18N
        diName4.setName("diName4"); // NOI18N
        diPanel.add(diName4);

        diValue4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue4.setText(resourceMap.getString("diValue4.text")); // NOI18N
        diValue4.setName("diValue4"); // NOI18N
        diPanel.add(diValue4);

        diName5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName5.setText(resourceMap.getString("diName5.text")); // NOI18N
        diName5.setName("diName5"); // NOI18N
        diPanel.add(diName5);

        diValue5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue5.setText(resourceMap.getString("diValue5.text")); // NOI18N
        diValue5.setName("diValue5"); // NOI18N
        diPanel.add(diValue5);

        diName6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName6.setText(resourceMap.getString("diName6.text")); // NOI18N
        diName6.setName("diName6"); // NOI18N
        diPanel.add(diName6);

        diValue6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue6.setText(resourceMap.getString("diValue6.text")); // NOI18N
        diValue6.setName("diValue6"); // NOI18N
        diPanel.add(diValue6);

        diName7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName7.setText(resourceMap.getString("diName7.text")); // NOI18N
        diName7.setName("diName7"); // NOI18N
        diPanel.add(diName7);

        diValue7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue7.setText(resourceMap.getString("diValue7.text")); // NOI18N
        diValue7.setName("diValue7"); // NOI18N
        diPanel.add(diValue7);

        diName8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName8.setText(resourceMap.getString("diName8.text")); // NOI18N
        diName8.setName("diName8"); // NOI18N
        diPanel.add(diName8);

        diValue8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue8.setText(resourceMap.getString("diValue8.text")); // NOI18N
        diValue8.setName("diValue8"); // NOI18N
        diPanel.add(diValue8);

        diName9.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName9.setText(resourceMap.getString("diName9.text")); // NOI18N
        diName9.setName("diName9"); // NOI18N
        diPanel.add(diName9);

        diValue9.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue9.setText(resourceMap.getString("diValue9.text")); // NOI18N
        diValue9.setName("diValue9"); // NOI18N
        diPanel.add(diValue9);

        diName10.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName10.setText(resourceMap.getString("diName10.text")); // NOI18N
        diName10.setName("diName10"); // NOI18N
        diPanel.add(diName10);

        diValue10.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue10.setText(resourceMap.getString("diValue10.text")); // NOI18N
        diValue10.setName("diValue10"); // NOI18N
        diPanel.add(diValue10);

        diName11.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName11.setText(resourceMap.getString("diName11.text")); // NOI18N
        diName11.setName("diName11"); // NOI18N
        diPanel.add(diName11);

        diValue11.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue11.setText(resourceMap.getString("diValue11.text")); // NOI18N
        diValue11.setName("diValue11"); // NOI18N
        diPanel.add(diValue11);

        diName12.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName12.setText(resourceMap.getString("diName12.text")); // NOI18N
        diName12.setName("diName12"); // NOI18N
        diPanel.add(diName12);

        diValue12.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue12.setText(resourceMap.getString("diValue12.text")); // NOI18N
        diValue12.setName("diValue12"); // NOI18N
        diPanel.add(diValue12);

        diName13.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName13.setText(resourceMap.getString("diName13.text")); // NOI18N
        diName13.setName("diName13"); // NOI18N
        diPanel.add(diName13);

        diValue13.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue13.setText(resourceMap.getString("diValue13.text")); // NOI18N
        diValue13.setName("diValue13"); // NOI18N
        diPanel.add(diValue13);

        diName14.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName14.setText(resourceMap.getString("diName14.text")); // NOI18N
        diName14.setName("diName14"); // NOI18N
        diPanel.add(diName14);

        diValue14.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue14.setText(resourceMap.getString("diValue14.text")); // NOI18N
        diValue14.setName("diValue14"); // NOI18N
        diPanel.add(diValue14);

        diName15.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName15.setText(resourceMap.getString("diName15.text")); // NOI18N
        diName15.setName("diName15"); // NOI18N
        diPanel.add(diName15);

        diValue15.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue15.setText(resourceMap.getString("diValue15.text")); // NOI18N
        diValue15.setName("diValue15"); // NOI18N
        diPanel.add(diValue15);

        diName16.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diName16.setText(resourceMap.getString("diName16.text")); // NOI18N
        diName16.setName("diName16"); // NOI18N
        diPanel.add(diName16);

        diValue16.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue16.setText(resourceMap.getString("diValue16.text")); // NOI18N
        diValue16.setName("diValue16"); // NOI18N
        diPanel.add(diValue16);

        mainPanel.add(diPanel);
        diPanel.setBounds(10, 200, 370, 340);
        diPanel.getAccessibleContext().setAccessibleName(resourceMap.getString("diPanel.AccessibleContext.accessibleName")); // NOI18N

        tiPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("tiPanel.border.title"))); // NOI18N
        tiPanel.setName("tiPanel"); // NOI18N
        tiPanel.setLayout(new java.awt.GridLayout(9, 2));

        jLabel4.setForeground(resourceMap.getColor("jLabel25.foreground")); // NOI18N
        jLabel4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel4.setText(resourceMap.getString("aiName1.text")); // NOI18N
        jLabel4.setName("aiName1"); // NOI18N
        tiPanel.add(jLabel4);

        jLabel7.setForeground(resourceMap.getColor("jLabel25.foreground")); // NOI18N
        jLabel7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel7.setText(resourceMap.getString("jLabel7.text")); // NOI18N
        jLabel7.setName("jLabel7"); // NOI18N
        tiPanel.add(jLabel7);

        tiName1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName1.setText(resourceMap.getString("tiName1.text")); // NOI18N
        tiName1.setName("tiName1"); // NOI18N
        tiPanel.add(tiName1);

        tiValue1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue1.setText(resourceMap.getString("tiValue1.text")); // NOI18N
        tiValue1.setName("tiValue1"); // NOI18N
        tiPanel.add(tiValue1);

        tiName2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName2.setText(resourceMap.getString("tiName2.text")); // NOI18N
        tiName2.setName("tiName2"); // NOI18N
        tiPanel.add(tiName2);

        tiValue2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue2.setText(resourceMap.getString("tiValue2.text")); // NOI18N
        tiValue2.setName("tiValue2"); // NOI18N
        tiPanel.add(tiValue2);

        tiName3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName3.setText(resourceMap.getString("tiName3.text")); // NOI18N
        tiName3.setName("tiName3"); // NOI18N
        tiPanel.add(tiName3);

        tiValue3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue3.setText(resourceMap.getString("tiValue3.text")); // NOI18N
        tiValue3.setName("tiValue3"); // NOI18N
        tiPanel.add(tiValue3);

        tiName4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName4.setText(resourceMap.getString("tiName4.text")); // NOI18N
        tiName4.setName("tiName4"); // NOI18N
        tiPanel.add(tiName4);

        tiValue4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue4.setText(resourceMap.getString("tiValue4.text")); // NOI18N
        tiValue4.setName("tiValue4"); // NOI18N
        tiPanel.add(tiValue4);

        tiName5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName5.setText(resourceMap.getString("tiName5.text")); // NOI18N
        tiName5.setName("tiName5"); // NOI18N
        tiPanel.add(tiName5);

        tiValue5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue5.setText(resourceMap.getString("tiValue5.text")); // NOI18N
        tiValue5.setName("tiValue5"); // NOI18N
        tiPanel.add(tiValue5);

        tiName6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName6.setText(resourceMap.getString("tiName6.text")); // NOI18N
        tiName6.setName("tiName6"); // NOI18N
        tiPanel.add(tiName6);

        tiValue6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue6.setText(resourceMap.getString("tiValue6.text")); // NOI18N
        tiValue6.setName("tiValue6"); // NOI18N
        tiPanel.add(tiValue6);

        tiName7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName7.setText(resourceMap.getString("tiName7.text")); // NOI18N
        tiName7.setName("tiName7"); // NOI18N
        tiPanel.add(tiName7);

        tiValue7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue7.setText(resourceMap.getString("tiValue7.text")); // NOI18N
        tiValue7.setName("tiValue7"); // NOI18N
        tiPanel.add(tiValue7);

        tiName8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiName8.setText(resourceMap.getString("tiName8.text")); // NOI18N
        tiName8.setName("tiName8"); // NOI18N
        tiPanel.add(tiName8);

        tiValue8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        tiValue8.setText(resourceMap.getString("tiValue8.text")); // NOI18N
        tiValue8.setName("tiValue8"); // NOI18N
        tiPanel.add(tiValue8);

        mainPanel.add(tiPanel);
        tiPanel.setBounds(400, 340, 380, 200);

        aiPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("aiPanel.border.title"))); // NOI18N
        aiPanel.setName("aiPanel"); // NOI18N
        aiPanel.setLayout(new java.awt.GridLayout(9, 2));

        jLabel24.setForeground(resourceMap.getColor("jLabel25.foreground")); // NOI18N
        jLabel24.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel24.setText(resourceMap.getString("jLabel24.text")); // NOI18N
        jLabel24.setName("jLabel24"); // NOI18N
        aiPanel.add(jLabel24);

        jLabel25.setForeground(resourceMap.getColor("jLabel25.foreground")); // NOI18N
        jLabel25.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabel25.setText(resourceMap.getString("jLabel25.text")); // NOI18N
        jLabel25.setName("jLabel25"); // NOI18N
        aiPanel.add(jLabel25);

        aiName1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName1.setText(resourceMap.getString("aiName1.text")); // NOI18N
        aiName1.setName("aiName1"); // NOI18N
        aiPanel.add(aiName1);

        aiValue1.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue1.setText(resourceMap.getString("aiValue1.text")); // NOI18N
        aiValue1.setName("aiValue1"); // NOI18N
        aiPanel.add(aiValue1);

        aiName2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName2.setText(resourceMap.getString("aiName2.text")); // NOI18N
        aiName2.setName("aiName2"); // NOI18N
        aiPanel.add(aiName2);

        aiValue2.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue2.setText(resourceMap.getString("aiValue2.text")); // NOI18N
        aiValue2.setName("aiValue2"); // NOI18N
        aiPanel.add(aiValue2);

        aiName3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName3.setText(resourceMap.getString("aiName3.text")); // NOI18N
        aiName3.setName("aiName3"); // NOI18N
        aiPanel.add(aiName3);

        aiValue3.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue3.setText(resourceMap.getString("aiValue3.text")); // NOI18N
        aiValue3.setName("aiValue3"); // NOI18N
        aiPanel.add(aiValue3);

        aiName4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName4.setText(resourceMap.getString("aiName4.text")); // NOI18N
        aiName4.setName("aiName4"); // NOI18N
        aiPanel.add(aiName4);

        aiValue4.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue4.setText(resourceMap.getString("aiValue4.text")); // NOI18N
        aiValue4.setName("aiValue4"); // NOI18N
        aiPanel.add(aiValue4);

        aiName5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName5.setText(resourceMap.getString("aiName5.text")); // NOI18N
        aiName5.setName("aiName5"); // NOI18N
        aiPanel.add(aiName5);

        aiValue5.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue5.setText(resourceMap.getString("aiValue5.text")); // NOI18N
        aiValue5.setName("aiValue5"); // NOI18N
        aiPanel.add(aiValue5);

        aiName6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName6.setText(resourceMap.getString("aiName6.text")); // NOI18N
        aiName6.setName("aiName6"); // NOI18N
        aiPanel.add(aiName6);

        aiValue6.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue6.setText(resourceMap.getString("aiValue6.text")); // NOI18N
        aiValue6.setName("aiValue6"); // NOI18N
        aiPanel.add(aiValue6);

        aiName7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName7.setText(resourceMap.getString("aiName7.text")); // NOI18N
        aiName7.setName("aiName7"); // NOI18N
        aiPanel.add(aiName7);

        aiValue7.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue7.setText(resourceMap.getString("aiValue7.text")); // NOI18N
        aiValue7.setName("aiValue7"); // NOI18N
        aiPanel.add(aiValue7);

        aiName8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiName8.setText(resourceMap.getString("aiName8.text")); // NOI18N
        aiName8.setName("aiName8"); // NOI18N
        aiPanel.add(aiName8);

        aiValue8.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        aiValue8.setText(resourceMap.getString("aiValue8.text")); // NOI18N
        aiValue8.setName("aiValue8"); // NOI18N
        aiPanel.add(aiValue8);

        mainPanel.add(aiPanel);
        aiPanel.setBounds(400, 140, 380, 200);

        pictureLabel.setIcon(resourceMap.getIcon("pictureLabel.icon")); // NOI18N
        pictureLabel.setText(resourceMap.getString("pictureLabel.text")); // NOI18N
        pictureLabel.setName("pictureLabel"); // NOI18N
        mainPanel.add(pictureLabel);
        pictureLabel.setBounds(70, 140, 250, 50);

        jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("jPanel1.border.title"))); // NOI18N
        jPanel1.setName("jPanel1"); // NOI18N
        jPanel1.setLayout(new java.awt.GridLayout(2, 3));

        diValue17.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue17.setText(resourceMap.getString("diValue17.text")); // NOI18N
        diValue17.setName("diValue17"); // NOI18N
        jPanel1.add(diValue17);

        diValue19.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue19.setText(resourceMap.getString("diValue19.text")); // NOI18N
        diValue19.setName("diValue19"); // NOI18N
        jPanel1.add(diValue19);

        diValue21.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        diValue21.setText(resourceMap.getString("diValue21.text")); // NOI18N
        diValue21.setName("diValue21"); // NOI18N
        jPanel1.add(diValue21);

        notificationLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        notificationLabel.setText(resourceMap.getString("notificationLabel.text")); // NOI18N
        notificationLabel.setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 0)));
        notificationLabel.setName("notificationLabel"); // NOI18N
        jPanel1.add(notificationLabel);

        datetimeLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        datetimeLabel.setText(resourceMap.getString("datetimeLabel.text")); // NOI18N
        datetimeLabel.setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 0)));
        datetimeLabel.setName("datetimeLabel"); // NOI18N
        jPanel1.add(datetimeLabel);

        deviceLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        deviceLabel.setText(resourceMap.getString("deviceLabel.text")); // NOI18N
        deviceLabel.setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(0, 0, 0)));
        deviceLabel.setName("deviceLabel"); // NOI18N
        jPanel1.add(deviceLabel);

        mainPanel.add(jPanel1);
        jPanel1.setBounds(10, 540, 770, 90);

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setText(resourceMap.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(smartDEN_Notifier_MQTT.smartDEN_Notifier_MQTTApp.class).getContext().getActionMap(smartDEN_Notifier_MQTTView.class, this);
        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exitMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setAction(actionMap.get("showAboutBox")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        statusPanel.setName("statusPanel"); // NOI18N

        statusMessageLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        statusMessageLabel.setText(resourceMap.getString("statusMessageLabel.text")); // NOI18N
        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addComponent(statusMessageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 113, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addGap(0, 0, 0)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(statusMessageLabel))
                .addGap(8, 8, 8))
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

    private void startButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startButtonActionPerformed
        // TODO add your handling code here:
        //mm.isrunning=true;
        mqttClient = new MyMqtt();
        mqttClient.readFromTopic();
        
        myMqtt = new myMqttThread();
        mqttThread = new Thread(myMqtt, "My Thread1");
        mqttThread.start();
        
        startButton.setEnabled(false);
        stopButton.setEnabled(true);
         myMqtt.SetRunning(true);
    }//GEN-LAST:event_startButtonActionPerformed

    private void stopButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_stopButtonActionPerformed
        mqttClient = null;
        
        myMqtt = null;
        mqttThread = null;
        
        stopButton.setEnabled(false);
        startButton.setEnabled(true);
        myMqtt.SetRunning(false);
        statusMessageLabel.setText("");          
    }//GEN-LAST:event_stopButtonActionPerformed

    private void exitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exitMenuItemActionPerformed
        // TODO add your handling code here:
        save();
    }//GEN-LAST:event_exitMenuItemActionPerformed

    public static void save()
    {
        PrintWriter writer;
        try {
            writer = new PrintWriter(System.getenv("APPDATA")+"\\textFieldOutput.txt", "UTF-8");
            writer.println(brokerText.getText());
            writer.println(portText.getText());
            writer.println(usernameText.getText());
            writer.println(passwordText.getText());
            writer.println(macText.getText());
            writer.println(periodText.getText());
            writer.close();
        } 
        catch (Exception ex)         
        {
            
        } 
        
    }
    
    public static void load()
    {
        BufferedReader br;
        try {
            br = new BufferedReader(new FileReader(System.getenv("APPDATA")+"\\textFieldOutput.txt"));
                try {
                StringBuilder sb = new StringBuilder();
                brokerText.setText(br.readLine());
                portText.setText(br.readLine());
                usernameText.setText(br.readLine());
                passwordText.setText(br.readLine());
                macText.setText(br.readLine());
                periodText.setText(br.readLine());
            
               
            } finally {
                br.close();
            }
        } catch (Exception ex) {
            
        }
        
    }
            
    // Variables declaration - do not modify//GEN-BEGIN:variables
    public static javax.swing.JLabel aiName1;
    public static javax.swing.JLabel aiName2;
    public static javax.swing.JLabel aiName3;
    public static javax.swing.JLabel aiName4;
    public static javax.swing.JLabel aiName5;
    public static javax.swing.JLabel aiName6;
    public static javax.swing.JLabel aiName7;
    public static javax.swing.JLabel aiName8;
    public static javax.swing.JPanel aiPanel;
    public static javax.swing.JLabel aiValue1;
    public static javax.swing.JLabel aiValue2;
    public static javax.swing.JLabel aiValue3;
    public static javax.swing.JLabel aiValue4;
    public static javax.swing.JLabel aiValue5;
    public static javax.swing.JLabel aiValue6;
    public static javax.swing.JLabel aiValue7;
    public static javax.swing.JLabel aiValue8;
    public static javax.swing.JTextField brokerText;
    public static javax.swing.JLabel datetimeLabel;
    public static javax.swing.JLabel deviceLabel;
    public static javax.swing.JLabel diName;
    public static javax.swing.JLabel diName1;
    public static javax.swing.JLabel diName10;
    public static javax.swing.JLabel diName11;
    public static javax.swing.JLabel diName12;
    public static javax.swing.JLabel diName13;
    public static javax.swing.JLabel diName14;
    public static javax.swing.JLabel diName15;
    public static javax.swing.JLabel diName16;
    public static javax.swing.JLabel diName2;
    public static javax.swing.JLabel diName3;
    public static javax.swing.JLabel diName4;
    public static javax.swing.JLabel diName5;
    public static javax.swing.JLabel diName6;
    public static javax.swing.JLabel diName7;
    public static javax.swing.JLabel diName8;
    public static javax.swing.JLabel diName9;
    public static javax.swing.JPanel diPanel;
    public static javax.swing.JLabel diValue;
    public static javax.swing.JLabel diValue1;
    public static javax.swing.JLabel diValue10;
    public static javax.swing.JLabel diValue11;
    public static javax.swing.JLabel diValue12;
    public static javax.swing.JLabel diValue13;
    public static javax.swing.JLabel diValue14;
    public static javax.swing.JLabel diValue15;
    public static javax.swing.JLabel diValue16;
    public static javax.swing.JLabel diValue17;
    public static javax.swing.JLabel diValue19;
    public static javax.swing.JLabel diValue2;
    public static javax.swing.JLabel diValue21;
    public static javax.swing.JLabel diValue3;
    public static javax.swing.JLabel diValue4;
    public static javax.swing.JLabel diValue5;
    public static javax.swing.JLabel diValue6;
    public static javax.swing.JLabel diValue7;
    public static javax.swing.JLabel diValue8;
    public static javax.swing.JLabel diValue9;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel24;
    private javax.swing.JLabel jLabel25;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JPanel jPanel1;
    public static javax.swing.JTextField macText;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JPanel mqttSettingsPanel;
    public static javax.swing.JLabel notificationLabel;
    public static javax.swing.JTextField passwordText;
    public static javax.swing.JTextField periodText;
    public static javax.swing.JLabel pictureLabel;
    public static javax.swing.JTextField portText;
    private javax.swing.JProgressBar progressBar;
    public static javax.swing.JButton startButton;
    private javax.swing.JLabel statusAnimationLabel;
    public static javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    public static javax.swing.JButton stopButton;
    public static javax.swing.JLabel tiName1;
    public static javax.swing.JLabel tiName2;
    public static javax.swing.JLabel tiName3;
    public static javax.swing.JLabel tiName4;
    public static javax.swing.JLabel tiName5;
    public static javax.swing.JLabel tiName6;
    public static javax.swing.JLabel tiName7;
    public static javax.swing.JLabel tiName8;
    public static javax.swing.JPanel tiPanel;
    public static javax.swing.JLabel tiValue1;
    public static javax.swing.JLabel tiValue2;
    public static javax.swing.JLabel tiValue3;
    public static javax.swing.JLabel tiValue4;
    public static javax.swing.JLabel tiValue5;
    public static javax.swing.JLabel tiValue6;
    public static javax.swing.JLabel tiValue7;
    public static javax.swing.JLabel tiValue8;
    public static javax.swing.JTextField usernameText;
    // End of variables declaration//GEN-END:variables

    private final Timer messageTimer;
    private final Timer busyIconTimer;
    private final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;

    private JDialog aboutBox;
    public static MyMqtt mqttClient;
    
    public static Thread mqttThread;
    myMqttThread myMqtt;
    
}
